@@ -4,8 +4,7 @@ test_that("Output rf",{
   library("DALEX")
   library("randomForest")
   set.seed(59)
-  apartments_rf_model <- randomForest(m2.price ~ construction.year + surface + floor +
-       no.rooms + district, data = apartments)
+  apartments_rf_model <- randomForest(m2.price ~., data = apartments)
   explainer_rf <- explain(apartments_rf_model,
        data = apartmentsTest[,2:6], y = apartmentsTest$m2.price, verbose = FALSE)
   new_apartment <- apartmentsTest[1, ]
